==> open5gs_2.4.9.tar.xz: BUILD/lib/pfcp/support/cache/tlv-msg-55.py <==
ies = []
ies.append({ "ie_type" : "Cause", "ie_value" : "Cause", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall indicate the acceptance or the rejection of the corresponding request message."})
ies.append({ "ie_type" : "Offending IE", "ie_value" : "Offending IE", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included if the rejection is due to a conditional or mandatory IE missing or faulty."})
ies.append({ "ie_type" : "Load Control Information", "ie_value" : "Load Control Information", "presence" : "O", "tlv_more" : "0", "comment" : "The UP function may include this IE if it supports the load control feature and the feature is activated in the network.See Table 7.5.3.3-1."})
ies.append({ "ie_type" : "Overload Control Information", "ie_value" : "Overload Control Information", "presence" : "O", "tlv_more" : "0", "comment" : "During an overload condition, the UP function may include this IE if it supports the overload control feature and the feature is activated in the network.See Table 7.5.3.4-1."})
type_list["Usage Report Session Deletion Response"]["max_tlv_more"] = "7"
ies.append({ "ie_type" : "Usage Report Session Deletion Response", "ie_value" : "Usage Report", "presence" : "C", "tlv_more" : "7", "comment" : "This IE shall be present if a URR had been provisioned in the UP function for the PFCP session being deleted and traffic usage measurements for that URR are available at the UP function.Several IEs within the same IE type may be present to represent a list of Usage Reports."})
ies.append({ "ie_type" : "Additional Usage Reports Information", "ie_value" : "Additional Usage Reports Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included if the usage reports need to be sent in additional PFCP Session Report Request messages (see clause5.2.2.3.1).When present, this IE shall either indicate that additional usage reports will follow, or indicate the total number of usage reports that need to be sent in PFCP Session Report Request messages."})
ies.append({ "ie_type" : "Packet Rate Status Report", "ie_value" : "Packet Rate Status Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the CP function has requested in a QER to report the packet rate status when the PFCP session is released and the UP function supports CIOT feature. (See clause8.2.25) "})
ies.append({ "ie_type" : "Session Report", "ie_value" : "Session Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if a SRR for QoS monitoring had been provisioned in the UP function for the PFCP session being deleted and QoS monitoring measurements for that SRR are available at the UP function. See Table7.5.8.7-1.Several IEs within the same IE type may be present to represent a list of Session Reports."})
msg_list[key]["ies"] = ies

==> open5gs_2.7.0.tar.xz: BUILD/lib/pfcp/support/cache/tlv-msg-55.py <==
ies = []
ies.append({ "ie_type" : "Cause", "ie_value" : "Cause", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall indicate the acceptance or the rejection of the corresponding request message."})
ies.append({ "ie_type" : "Offending IE", "ie_value" : "Offending IE", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included if the rejection is due to a conditional or mandatory IE missing or faulty."})
ies.append({ "ie_type" : "Load Control Information", "ie_value" : "Load Control Information", "presence" : "O", "tlv_more" : "0", "comment" : "The UP function may include this IE if it supports the load control feature and the feature is activated in the network.See Table 7.5.3.3-1."})
ies.append({ "ie_type" : "Overload Control Information", "ie_value" : "Overload Control Information", "presence" : "O", "tlv_more" : "0", "comment" : "During an overload condition, the UP function may include this IE if it supports the overload control feature and the feature is activated in the network.See Table 7.5.3.4-1."})
type_list["Usage Report Session Deletion Response"]["max_tlv_more"] = "7"
ies.append({ "ie_type" : "Usage Report Session Deletion Response", "ie_value" : "Usage Report", "presence" : "C", "tlv_more" : "7", "comment" : "This IE shall be present if a URR had been provisioned in the UP function for the PFCP session being deleted and traffic usage measurements for that URR are available at the UP function.Several IEs within the same IE type may be present to represent a list of Usage Reports."})
ies.append({ "ie_type" : "Additional Usage Reports Information", "ie_value" : "Additional Usage Reports Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included if the usage reports need to be sent in additional PFCP Session Report Request messages (see clause5.2.2.3.1).When present, this IE shall either indicate that additional usage reports will follow, or indicate the total number of usage reports that need to be sent in PFCP Session Report Request messages."})
ies.append({ "ie_type" : "Packet Rate Status Report", "ie_value" : "Packet Rate Status Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the CP function has requested in a QER to report the packet rate status when the PFCP session is released and the UP function supports CIOT feature. (See clause8.2.25) "})
ies.append({ "ie_type" : "Session Report", "ie_value" : "Session Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if a SRR for QoS monitoring had been provisioned in the UP function for the PFCP session being deleted and QoS monitoring measurements for that SRR are available at the UP function. See Table7.5.8. 6-1.Several IEs within the same IE type may be present to represent a list of Session Reports."})
ies.append({ "ie_type" : "MBS Session N4 Information", "ie_value" : "MBS Session N4 Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included if any IE in this grouped IE needs to be included as specified in clause5.34.1.Several IE with the same IE type may be present to contain N4 Information for several MBS Sessions.See Table 7.5.3.1-5 for encoding."})
ies.append({ "ie_type" : "PFCPSDRsp-Flags", "ie_value" : "PFCPSDRsp-Flags", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included if at least one of the flags is set to 1.-	PURU (Pending Usage Reports Unacknowledged): the UP function shall set this flag if the UP function has pending PFCP Session Report Request messages which have not been acknowledged yet when it sends the PFCP Session Deletion Response message."})
msg_list[key]["ies"] = ies
